# OpenAPISpecDiff

OpenAPISpecDiff is a Python library for comparing two OpenAPI specs and identifying the difference between them. 

Visit https://www.cloudvector.com/api-shark-free-observability-security-monitoring-tool/#apishark

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install openapispecdiff
```

## Usage

```python openapispecdiff 

****************************************************************************************************
CloudVector APIShark - OpenAPI spec diff checker plugin
****************************************************************************************************
Enter absolute path to Old API SPEC: ../input.json
Enter absolute path to new API SPEC : ../input1.json 
```

## License
[MIT](https://choosealicense.com/licenses/mit/)